'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsCore = require('@lorisleiva/js-core');
var web3_js = require('@solana/web3.js');
var TransactionMessage = require('./TransactionMessage.cjs');

function fromWeb3JsTransaction(transaction) {
  return {
    message: TransactionMessage.fromWeb3JsMessage(transaction.message),
    serializedMessage: transaction.message.serialize(),
    signatures: transaction.signatures
  };
}
function toWeb3JsTransaction(transaction) {
  return new web3_js.VersionedTransaction(TransactionMessage.toWeb3JsMessage(transaction.message), transaction.signatures);
}
function fromWeb3JsLegacyTransaction(transaction) {
  const message = transaction.compileMessage();
  return {
    message: TransactionMessage.fromWeb3JsMessage(message),
    serializedMessage: message.serialize(),
    signatures: transaction.signatures.map(signature => new Uint8Array(signature.signature))
  };
}
function toWeb3JsLegacyTransaction(transaction) {
  const web3JsTransaction = toWeb3JsTransaction(transaction);
  return web3_js.Transaction.populate(web3JsTransaction.message, web3JsTransaction.signatures.map(signature => jsCore.base58.deserialize(signature)[0]));
}

exports.fromWeb3JsLegacyTransaction = fromWeb3JsLegacyTransaction;
exports.fromWeb3JsTransaction = fromWeb3JsTransaction;
exports.toWeb3JsLegacyTransaction = toWeb3JsLegacyTransaction;
exports.toWeb3JsTransaction = toWeb3JsTransaction;
//# sourceMappingURL=Transaction.cjs.map
