import { base58 } from '@lorisleiva/js-core';
import { VersionedTransaction, Transaction } from '@solana/web3.js';
import { fromWeb3JsMessage, toWeb3JsMessage } from './TransactionMessage.mjs';

function fromWeb3JsTransaction(transaction) {
  return {
    message: fromWeb3JsMessage(transaction.message),
    serializedMessage: transaction.message.serialize(),
    signatures: transaction.signatures
  };
}
function toWeb3JsTransaction(transaction) {
  return new VersionedTransaction(toWeb3JsMessage(transaction.message), transaction.signatures);
}
function fromWeb3JsLegacyTransaction(transaction) {
  const message = transaction.compileMessage();
  return {
    message: fromWeb3JsMessage(message),
    serializedMessage: message.serialize(),
    signatures: transaction.signatures.map(signature => new Uint8Array(signature.signature))
  };
}
function toWeb3JsLegacyTransaction(transaction) {
  const web3JsTransaction = toWeb3JsTransaction(transaction);
  return Transaction.populate(web3JsTransaction.message, web3JsTransaction.signatures.map(signature => base58.deserialize(signature)[0]));
}

export { fromWeb3JsLegacyTransaction, fromWeb3JsTransaction, toWeb3JsLegacyTransaction, toWeb3JsTransaction };
//# sourceMappingURL=Transaction.mjs.map
